@@ -23,6 +23,7 @@ from recipe.schemas.config_constructors import (
 )
 from recipe.schemas.config_constructors import parse_unvalidated_field as parse_field
 from recipe.schemas.config_constructors import SAFE_DIVISON_EPSILON
+from recipe.utils import filter_to_string
 
 
 class TestIngredients(object):
@@ -133,40 +134,40 @@ class TestIngredients(object):
 
 
 class TestIngredientBuildFilter(object):
-    def test_scalar_fitler(self):
+    def test_scalar_filter(self):
         """Test scalar filters on a string dimension """
         d = Dimension(MyTable.first)
 
         # Test building scalar filters
         filt = d.build_filter("moo")
-        assert str(filt.filters[0]) == "foo.first = :first_1"
+        assert filter_to_string(filt) == "foo.first = 'moo'"
         filt = d.build_filter("moo", "eq")
-        assert str(filt.filters[0]) == "foo.first = :first_1"
+        assert filter_to_string(filt) == "foo.first = 'moo'"
         filt = d.build_filter("moo", "ne")
-        assert str(filt.filters[0]) == "foo.first != :first_1"
+        assert filter_to_string(filt) == "foo.first != 'moo'"
         filt = d.build_filter("moo", "lt")
-        assert str(filt.filters[0]) == "foo.first < :first_1"
+        assert filter_to_string(filt) == "foo.first < 'moo'"
         filt = d.build_filter("moo", "lte")
-        assert str(filt.filters[0]) == "foo.first <= :first_1"
+        assert filter_to_string(filt) == "foo.first <= 'moo'"
         filt = d.build_filter("moo", "gt")
-        assert str(filt.filters[0]) == "foo.first > :first_1"
+        assert filter_to_string(filt) == "foo.first > 'moo'"
         filt = d.build_filter("moo", "gte")
-        assert str(filt.filters[0]) == "foo.first >= :first_1"
+        assert filter_to_string(filt) == "foo.first >= 'moo'"
         filt = d.build_filter("moo", "is")
-        assert str(filt.filters[0]) == "foo.first IS :first_1"
+        assert filter_to_string(filt) == "foo.first IS 'moo'"
         filt = d.build_filter("moo", "isnot")
-        assert str(filt.filters[0]) == "foo.first IS NOT :first_1"
+        assert filter_to_string(filt) == "foo.first IS NOT 'moo'"
         filt = d.build_filter("moo", "like")
-        assert str(filt.filters[0]) == "foo.first LIKE :first_1"
+        assert filter_to_string(filt) == "foo.first LIKE 'moo'"
         filt = d.build_filter("moo", "ilike")
-        assert str(filt.filters[0]) == "lower(foo.first) LIKE lower(:first_1)"
+        assert filter_to_string(filt) == "lower(foo.first) LIKE lower('moo')"
         # None values get converted to IS
         filt = d.build_filter(None, "eq")
-        assert str(filt.filters[0]) == "foo.first IS NULL"
+        assert filter_to_string(filt) == "foo.first IS NULL"
 
         # str filter values are acceptable
         filt = d.build_filter(u"Τη γλώσ")
-        assert str(filt.filters[0]) == "foo.first = :first_1"
+        assert filter_to_string(filt) == "foo.first = 'Τη γλώσ'"
 
         # operator must agree with value
         with pytest.raises(ValueError):
@@ -178,43 +179,43 @@ class TestIngredientBuildFilter(object):
         with pytest.raises(ValueError):
             filt = d.build_filter(["moo"], "cows")
 
-    def test_scalar_fitler_on_int(self):
+    def test_scalar_filter_on_int(self):
         """Test scalar filters on an integer dimension """
         d = Dimension(MyTable.age)
 
         # Test building scalar filters
         filt = d.build_filter("moo")
-        assert str(filt.filters[0]) == "CAST(foo.age AS VARCHAR) = :param_1"
+        assert filter_to_string(filt) == "CAST(foo.age AS VARCHAR) = 'moo'"
         filt = d.build_filter("moo", "eq")
-        assert str(filt.filters[0]) == "CAST(foo.age AS VARCHAR) = :param_1"
+        assert filter_to_string(filt) == "CAST(foo.age AS VARCHAR) = 'moo'"
         filt = d.build_filter("moo", "ne")
-        assert str(filt.filters[0]) == "CAST(foo.age AS VARCHAR) != :param_1"
+        assert filter_to_string(filt) == "CAST(foo.age AS VARCHAR) != 'moo'"
         filt = d.build_filter("moo", "lt")
-        assert str(filt.filters[0]) == "CAST(foo.age AS VARCHAR) < :param_1"
+        assert filter_to_string(filt) == "CAST(foo.age AS VARCHAR) < 'moo'"
         filt = d.build_filter("moo", "lte")
-        assert str(filt.filters[0]) == "CAST(foo.age AS VARCHAR) <= :param_1"
+        assert filter_to_string(filt) == "CAST(foo.age AS VARCHAR) <= 'moo'"
         filt = d.build_filter("moo", "gt")
-        assert str(filt.filters[0]) == "CAST(foo.age AS VARCHAR) > :param_1"
+        assert filter_to_string(filt) == "CAST(foo.age AS VARCHAR) > 'moo'"
         filt = d.build_filter("moo", "gte")
-        assert str(filt.filters[0]) == "CAST(foo.age AS VARCHAR) >= :param_1"
+        assert filter_to_string(filt) == "CAST(foo.age AS VARCHAR) >= 'moo'"
         filt = d.build_filter("moo", "is")
-        assert str(filt.filters[0]) == "CAST(foo.age AS VARCHAR) IS :param_1"
+        assert filter_to_string(filt) == "CAST(foo.age AS VARCHAR) IS 'moo'"
         filt = d.build_filter("moo", "isnot")
-        assert str(filt.filters[0]) == "CAST(foo.age AS VARCHAR) IS NOT :param_1"
+        assert filter_to_string(filt) == "CAST(foo.age AS VARCHAR) IS NOT 'moo'"
         filt = d.build_filter("moo", "like")
-        assert str(filt.filters[0]) == "CAST(foo.age AS VARCHAR) LIKE :param_1"
+        assert filter_to_string(filt) == "CAST(foo.age AS VARCHAR) LIKE 'moo'"
         filt = d.build_filter("moo", "ilike")
         assert (
-            str(filt.filters[0])
-            == "lower(CAST(foo.age AS VARCHAR)) LIKE lower(:param_1)"
+            filter_to_string(filt)
+            == "lower(CAST(foo.age AS VARCHAR)) LIKE lower('moo')"
         )
         # None values get converted to IS
         filt = d.build_filter(None, "eq")
-        assert str(filt.filters[0]) == "foo.age IS NULL"
+        assert filter_to_string(filt) == "foo.age IS NULL"
 
         # str filter values are acceptable
         filt = d.build_filter(u"Τη γλώσ")
-        assert str(filt.filters[0]) == "CAST(foo.age AS VARCHAR) = :param_1"
+        assert filter_to_string(filt) == "CAST(foo.age AS VARCHAR) = 'Τη γλώσ'"
 
         # operator must agree with value
         with pytest.raises(ValueError):
@@ -226,36 +227,36 @@ class TestIngredientBuildFilter(object):
         with pytest.raises(ValueError):
             d.build_filter(["moo"], "cows")
 
-    def test_scalar_fitler_on_int_dim_int_value(self):
+    def test_scalar_filter_on_int_dim_int_value(self):
         """Test scalar filters on an integer dimension passing an integer value"""
         d = Dimension(MyTable.age)
 
         # Test building scalar filters
         filt = d.build_filter(5)
-        assert str(filt.filters[0]) == "foo.age = :age_1"
+        assert filter_to_string(filt) == "foo.age = 5"
         filt = d.build_filter(5, "eq")
-        assert str(filt.filters[0]) == "foo.age = :age_1"
+        assert filter_to_string(filt) == "foo.age = 5"
         filt = d.build_filter(5, "ne")
-        assert str(filt.filters[0]) == "foo.age != :age_1"
+        assert filter_to_string(filt) == "foo.age != 5"
         filt = d.build_filter(5, "lt")
-        assert str(filt.filters[0]) == "foo.age < :age_1"
+        assert filter_to_string(filt) == "foo.age < 5"
         filt = d.build_filter(5, "lte")
-        assert str(filt.filters[0]) == "foo.age <= :age_1"
+        assert filter_to_string(filt) == "foo.age <= 5"
         filt = d.build_filter(5, "gt")
-        assert str(filt.filters[0]) == "foo.age > :age_1"
+        assert filter_to_string(filt) == "foo.age > 5"
         filt = d.build_filter(5, "gte")
-        assert str(filt.filters[0]) == "foo.age >= :age_1"
+        assert filter_to_string(filt) == "foo.age >= 5"
         filt = d.build_filter(5, "is")
-        assert str(filt.filters[0]) == "foo.age IS :age_1"
+        assert filter_to_string(filt) == "foo.age IS 5"
         filt = d.build_filter(5, "isnot")
-        assert str(filt.filters[0]) == "foo.age IS NOT :age_1"
+        assert filter_to_string(filt) == "foo.age IS NOT 5"
         # None values get converted to IS
         filt = d.build_filter(None, "eq")
-        assert str(filt.filters[0]) == "foo.age IS NULL"
+        assert filter_to_string(filt) == "foo.age IS NULL"
 
         # str filter values are acceptable
         filt = d.build_filter(u"Τη γλώσ")
-        assert str(filt.filters[0]) == "CAST(foo.age AS VARCHAR) = :param_1"
+        assert filter_to_string(filt) == "CAST(foo.age AS VARCHAR) = 'Τη γλώσ'"
 
         # operator must agree with value
         with pytest.raises(ValueError):
@@ -278,34 +279,35 @@ class TestIngredientBuildFilter(object):
 
         # Test building scalar filters
         filt = d.build_filter(["moo"])
-        assert str(filt.filters[0]) == "foo.first IN (:first_1)"
+        assert filter_to_string(filt) == "foo.first IN ('moo')"
         filt = d.build_filter(["moo", None])
-        assert str(filt.filters[0]) == "foo.first IS NULL OR foo.first IN (:first_1)"
+        assert filter_to_string(filt) == "foo.first IS NULL OR foo.first IN ('moo')"
         filt = d.build_filter([None, "moo", None, None])
-        assert str(filt.filters[0]) == "foo.first IS NULL OR foo.first IN (:first_1)"
+        assert filter_to_string(filt) == "foo.first IS NULL OR foo.first IN ('moo')"
         filt = d.build_filter([None, None])
-        assert str(filt.filters[0]) == "foo.first IS NULL"
+        assert filter_to_string(filt) == "foo.first IS NULL"
 
         filt = d.build_filter(["moo", "foo"])
-        assert str(filt.filters[0]) == "foo.first IN (:first_1, :first_2)"
+        # Values are sorted
+        assert filter_to_string(filt) == "foo.first IN ('foo', 'moo')"
         filt = d.build_filter(["moo"], operator="in")
-        assert str(filt.filters[0]) == "foo.first IN (:first_1)"
+        assert filter_to_string(filt) == "foo.first IN ('moo')"
         filt = d.build_filter(["moo"], operator="notin")
-        assert str(filt.filters[0]) == "foo.first NOT IN (:first_1)"
+        assert filter_to_string(filt) == "foo.first NOT IN ('moo')"
         filt = d.build_filter(["moo", None], operator="notin")
         assert (
-            str(filt.filters[0])
-            == "foo.first IS NOT NULL AND foo.first NOT IN (:first_1)"
+            filter_to_string(filt)
+            == "foo.first IS NOT NULL AND foo.first NOT IN ('moo')"
         )
         filt = d.build_filter([None, "moo", None], operator="notin")
         assert (
-            str(filt.filters[0])
-            == "foo.first IS NOT NULL AND foo.first NOT IN (:first_1)"
+            filter_to_string(filt)
+            == "foo.first IS NOT NULL AND foo.first NOT IN ('moo')"
         )
         filt = d.build_filter([None, None], operator="notin")
-        assert str(filt.filters[0]) == "foo.first IS NOT NULL"
+        assert filter_to_string(filt) == "foo.first IS NOT NULL"
         filt = d.build_filter(["moo", "foo"], operator="between")
-        assert str(filt.filters[0]) == "foo.first BETWEEN :first_1 AND :first_2"
+        assert filter_to_string(filt) == "foo.first BETWEEN 'moo' AND 'foo'"
 
         with pytest.raises(ValueError):
             d.build_filter("moo", "in")
@@ -315,6 +317,78 @@ class TestIngredientBuildFilter(object):
         with pytest.raises(ValueError):
             d.build_filter(["moo"], operator="between")
 
+    def test_scalar_filter_date(self):
+        d = Dimension(MyTable.birth_date)
+        # Test building scalar filters
+        filt = d.build_filter("2020-01-01")
+        assert filter_to_string(filt) == "foo.birth_date = '2020-01-01'"
+
+        filt = d.build_filter("2020-01-01T03:05")
+        assert filter_to_string(filt) == "foo.birth_date = '2020-01-01'"
+
+        # An unparsable date will be treated as a string
+        filt = d.build_filter("2020-01-01T03:05X523")
+        assert (
+            filter_to_string(filt)
+            == "CAST(foo.birth_date AS VARCHAR) = '2020-01-01T03:05X523'"
+        )
+
+        # Evaluated as timestamp=0
+        filt = d.build_filter(0)
+        assert filter_to_string(filt) == "foo.birth_date = '1970-01-01'"
+
+    def test_scalar_filter_datetime(self):
+        d = Dimension(MyTable.dt)
+        # Test building scalar filters
+        filt = d.build_filter("2020-01-01")
+        assert filter_to_string(filt) == "foo.dt = '2020-01-01 00:00:00'"
+
+        filt = d.build_filter("2020-01-01T03:05")
+        assert filter_to_string(filt) == "foo.dt = '2020-01-01 03:05:00'"
+
+        filt = d.build_filter("2020-01-01T03:05 UTC")
+        assert filter_to_string(filt) == "foo.dt = '2020-01-01 03:05:00+00:00'"
+
+        filt = d.build_filter("2020-01-01T04:06:01Z")
+        assert filter_to_string(filt) == "foo.dt = '2020-01-01 04:06:01+00:00'"
+
+        filt = d.build_filter("2020-01-01T03:05 EST")
+        assert filter_to_string(filt) == "foo.dt = '2020-01-01 03:05:00-05:00'"
+
+        filt = d.build_filter("2020-01-01T06:07:04.123456")
+        assert filter_to_string(filt) == "foo.dt = '2020-01-01 06:07:04.123456'"
+
+        # An unparsable date will be treated as a string
+        filt = d.build_filter("2020-01-01T03:05X523")
+        assert (
+            filter_to_string(filt) == "CAST(foo.dt AS VARCHAR) = '2020-01-01T03:05X523'"
+        )
+
+        # Evaluated as timestamp=0
+        filt = d.build_filter(0)
+        assert filter_to_string(filt) == "foo.dt = '1970-01-01 00:00:00'"
+
+    def test_vector_filter_date(self):
+        d = Dimension(MyTable.birth_date)
+        # Test building scalar filters
+        filt = d.build_filter(["2020-01-01", None, "2020-10-25"])
+        assert (
+            filter_to_string(filt)
+            == "foo.birth_date IS NULL OR foo.birth_date IN ('2020-01-01', '2020-10-25')"
+        )
+
+        filt = d.build_filter([0])
+        assert filter_to_string(filt) == "foo.birth_date IN ('1970-01-01')"
+
+        seconds_in_day = 24 * 60 * 60
+        filt = d.build_filter([seconds_in_day + 0.123565, None, 0])
+        assert (
+            filter_to_string(filt)
+            == "foo.birth_date IS NULL OR foo.birth_date IN ('1970-01-01', '1970-01-02')"
+        )
+        filt = d.build_filter([seconds_in_day * 3], operator="notin")
+        assert filter_to_string(filt) == "foo.birth_date NOT IN ('1970-01-04')"
+
     def test_quickselects(self):
         d = Dimension(
             MyTable.first,
@@ -326,9 +400,9 @@ class TestIngredientBuildFilter(object):
 
         # Test building scalar filters
         filt = d.build_filter("a", operator="quickselect")
-        assert str(filt.filters[0]) == "foo.first = :first_1"
+        assert filter_to_string(filt) == "foo.first = 'a'"
         filt = d.build_filter("b", operator="quickselect")
-        assert str(filt.filters[0]) == "foo.last = :last_1"
+        assert filter_to_string(filt) == "foo.last = 'b'"
 
         with pytest.raises(ValueError):
             filt = d.build_filter("c", operator="quickselect")
@@ -343,13 +417,13 @@ class TestIngredientBuildFilter(object):
 
         # Test building vector filters
         filt = d.build_filter(["a"], operator="quickselect")
-        assert str(filt.filters[0]) == "foo.first = :first_1"
+        assert filter_to_string(filt) == "foo.first = 'a'"
         filt = d.build_filter(["b"], operator="quickselect")
-        assert str(filt.filters[0]) == "foo.last = :last_1"
+        assert filter_to_string(filt) == "foo.last = 'b'"
         filt = d.build_filter(["a", "b"], operator="quickselect")
-        assert str(filt.filters[0]) == "foo.first = :first_1 OR foo.last = :last_1"
+        assert filter_to_string(filt) == "foo.first = 'a' OR foo.last = 'b'"
         filt = d.build_filter(["b", "a"], operator="quickselect")
-        assert str(filt.filters[0]) == "foo.last = :last_1 OR foo.first = :first_1"
+        assert filter_to_string(filt) == "foo.last = 'b' OR foo.first = 'a'"
 
         with pytest.raises(ValueError):
             filt = d.build_filter(["c"], operator="quickselect")
